<?php
/**
 * dolphin. Collection of useful PHP skeletons.
 * Copyright (C) 2013-2020  Johannes 'Banana' Keßler
 *
 * https://www.bananas-playground.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the COMMON DEVELOPMENT AND DISTRIBUTION LICENSE
 *
 * You should have received a copy of the
 * COMMON DEVELOPMENT AND DISTRIBUTION LICENSE (CDDL) Version 1.0
 * along with this program.  If not, see http://www.sun.com/cddl/cddl.html
 */

/**
 * Class TitleAkas
 * Import the data from imdb dataset title.akas.tsv
 */
class TitleAkas extends TSVImport {

    public function setup() {
        $this->_db_table_name = 'title_akas';
        $this->_db_table_crate_str = "CREATE TABLE `".$this->_db_table_name."` (
`titleId` varchar(16) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
`ordering` int NOT NULL,
`title` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
`region` varchar(8) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
`language` varchar(64) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
`types` varchar(128) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
`attributes` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
`isOriginalTitle` tinyint(1) NOT NULL,
UNIQUE KEY `titleId` (`titleId`,`ordering`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin";

        if($this->_createFulltext) {
            $this->_db_table_after_import_query[] = "ALTER TABLE `" . $this->_db_table_name . "` ADD FULLTEXT (`title`)";
            $this->_db_table_after_import_query[] = "OPTIMIZE TABLE `" . $this->_db_table_name . "`";
        }
    }

    public function queryValuePart($data) {
        $ret = '';

        if(!empty($data)) {
            if(!isset($data[7])) {
                return $ret;
            }
            $ret .= "(
                '".$this->_DB->real_escape_string($data[0])."',
                '".$this->_DB->real_escape_string($data[1])."',
                '".$this->_DB->real_escape_string($data[2])."',
                '".$this->_DB->real_escape_string($data[3])."',
                '".$this->_DB->real_escape_string($data[4])."',
                '".$this->_DB->real_escape_string($data[5])."',
                '".$this->_DB->real_escape_string($data[6])."',
                '".$this->_DB->real_escape_string($data[7])."'
            )";
        }

        return $ret;
    }
}
